@@ -4,13 +4,14 @@ use Dancer qw/:syntax :script/;
 use Dancer::Plugin::DBIC 'schema';
 
 use App::Netdisco::Util::Device 'get_device';
+use App::Netdisco::Util::Permission qw/check_acl_no check_acl_only/;
 
 use base 'Exporter';
 our @EXPORT = ();
 our @EXPORT_OK = qw/
   vlan_reconfig_check port_reconfig_check
   get_port get_iid get_powerid
-  is_vlan_interface port_has_phone
+  is_vlan_interface port_has_phone port_has_wap
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -68,6 +69,10 @@ sub vlan_reconfig_check {
 
 =item *
 
+Permission check that C<portctl_no> and C<portctl_only> pass for the device.
+
+=item *
+
 Permission check that C<portctl_nameonly> is false in Netdisco config.
 
 =item *
@@ -96,9 +101,16 @@ sub port_reconfig_check {
   my $ip = $port->ip;
   my $name = $port->port;
 
+  my $has_wap   = port_has_wap($port);
   my $has_phone = port_has_phone($port);
   my $is_vlan   = is_vlan_interface($port);
 
+  # check for limits on devices
+  return "forbidden: device [$ip] is in denied ACL"
+    if check_acl_no($ip, 'portctl_no');
+  return "forbidden: device [$ip] is not in permitted ACL"
+    unless check_acl_only($ip, 'portctl_only');
+
   # only permitted to change interface name
   return "forbidden: not permitted to change port configuration"
     if setting('portctl_nameonly');
@@ -108,6 +120,10 @@ sub port_reconfig_check {
     if ($port->is_uplink or $port->remote_type)
         and not $has_phone and not setting('portctl_uplinks');
 
+  # wap check
+  return "forbidden: port [$name] on [$ip] is a wireless ap"
+    if $has_wap and setting('portctl_nowaps');
+
   # phone check
   return "forbidden: port [$name] on [$ip] is a phone"
     if $has_phone and setting('portctl_nophones');
@@ -223,4 +239,15 @@ sub port_has_phone {
   return ($properties ? $properties->remote_is_phone : undef);
 }
 
+=head2 port_has_wap( $port )
+
+Returns true if the C<$port> L<DBIx::Class> object has a wireless AP  connected.
+
+=cut
+
+sub port_has_wap {
+  my $properties = (shift)->properties;
+  return ($properties ? $properties->remote_is_wap : undef);
+}
+
 1;
