@@ -11,6 +11,7 @@ register_report(
         tag      => 'portvlanmismatch',
         label    => 'Port VLAN Mismatches',
         provides_csv => 1,
+        api_endpoint => 1,
     }
 );
 
@@ -20,13 +21,11 @@ get '/ajax/content/report/portvlanmismatch' => require_login sub {
 
     if (request->is_ajax) {
         my $json = to_json (\@results);
-        template 'ajax/report/portvlanmismatch.tt', { results => $json },
-            { layout => undef };
+        template 'ajax/report/portvlanmismatch.tt', { results => $json };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
-        template 'ajax/report/portvlanmismatch_csv.tt', { results => \@results, },
-            { layout => undef };
+        template 'ajax/report/portvlanmismatch_csv.tt', { results => \@results, };
     }
 };
 
